#
# spec file for package libgsm
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libgsm
%define _name gsm
Version:        1.0.14
Release:        lp150.1.9
%define _version 1.0-pl14
Summary:        GSM 06.10 Lossy Speech Compressor Library and Utilities
License:        ISC
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Source:         http://www.quut.com/gsm/%{_name}-%{version}.tar.gz
Source2:        baselibs.conf
Url:            http://www.quut.com/gsm/
# This is a Debian patch file with debian chunks removed.
Patch:          %{name}-1.0.13.patch
Patch1:         libgsm-paths.patch
Patch2:         libgsm-include.patch
Patch3:         libgsm-strict-aliasing.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libgsm implements the European GSM 06.10 provisional standard for
full-rate speech transcoding, prI-ETS 300 036, which uses RPE/LTP
coding at 13 kbit/s. GSM 06.10 compresses frames of 160 13-bit
samples (8 kHz sampling rate) into 260 bits.

%package -n libgsm1
Summary:        GSM 06.10 Lossy Speech Compressor Library and Utilities
Group:          Productivity/Multimedia/Sound/Editors and Convertors
# Last appeared in OpenSUSE 10.3:
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libgsm1
Contains the library for a GSM speech compressor.

libgsm implements the European GSM 06.10 provisional standard for
full-rate speech transcoding, prI-ETS 300 036, which uses RPE/LTP
(residual pulse excitation/long term prediction) coding at 13 kbit/s.
GSM 06.10 compresses frames of 160 13-bit samples (8 kHz sampling
rate) into 260 bits.

%package utils
Summary:        GSM 06.10 Lossy Speech Compressor Library and Utilities
Group:          Productivity/Multimedia/Sound/Editors and Convertors
# Last appeared in OpenSUSE 10.3:
Provides:       %{name}:%{_bindir}/toast

%description utils
Contains binaries for a GSM speech compressor, verified against the
ETSI standard test patterns.

libgsm implements the European GSM 06.10 provisional standard for
full-rate speech transcoding, prI-ETS 300 036, which uses RPE/LTP
(residual pulse excitation/long term prediction) coding at 13 kbit/s.
GSM 06.10 compresses frames of 160 13-bit samples (8 kHz sampling
rate) into 260 bits.

The front-end is modeled after the historic compress(1) utility.

%package devel
Summary:        GSM 06.10 Lossy Speech Compressor Library and Utilities
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Requires:       libgsm1 = %{version}

%description devel
Contains the development kit for the libgsm speech compressor.

libgsm implements the European GSM 06.10 provisional standard for
full-rate speech transcoding, prI-ETS 300 036, which uses RPE/LTP
coding at 13 kbit/s. GSM 06.10 compresses frames of 160 13-bit
samples (8 kHz sampling rate) into 260 bits.

This implementation turns frames of 160 16-bit linear samples into
33-byte frames (1650 bytes/s) and has been verified against the ETSI
standard test patterns.

%prep
%setup -n %{_name}-%{_version}
%patch -p1
%patch1
%patch2
%patch3

%build
make CCFLAGS="-c $RPM_OPT_FLAGS -D_POSIX_SOURCE -D_BSD_SOURCE -DNeedFunctionPrototypes=1" lib/libgsm.a
cp lib/libgsm.a lib/libgsm.a.save
make clean
make CCFLAGS="-c $RPM_OPT_FLAGS -D_POSIX_SOURCE -D_BSD_SOURCE -DNeedFunctionPrototypes=1 -fPIC"
cp lib/libgsm.a.save lib/libgsm.a
touch lib/libgsm.a

%install
mkdir -p $RPM_BUILD_ROOT%{_prefix}/{include/gsm,%{_lib},bin,share/man/man{1,3}}
make INSTALL_ROOT=$RPM_BUILD_ROOT%{_prefix} GSM_INSTALL_LIB=$RPM_BUILD_ROOT%{_libdir} install
cp -d lib/libgsm.so* $RPM_BUILD_ROOT%{_libdir}
( cd $RPM_BUILD_ROOT%{_libdir} ; ln -sf libgsm.so.1 libgsm.so )
cp inc/{private.h,proto.h,unproto.h} $RPM_BUILD_ROOT%{_includedir}/gsm/
%{__rm} -f %{buildroot}%{_libdir}/*.a

%post -n libgsm1 -p /sbin/ldconfig

%postun -n libgsm1 -p /sbin/ldconfig

%files utils
%defattr (-, root, root)
%{_bindir}/*
%doc %{_mandir}/man1/*.*

%files -n libgsm1
%defattr (-, root, root)
%doc COPYRIGHT ChangeLog MACHINES README
%{_libdir}/*.so.*

%files devel
%defattr (-, root, root)
%{_libdir}/*.so
%doc %{_mandir}/man3/*.*
%{_includedir}/gsm

%changelog
* Sat Nov  7 2015 jengelh@inai.de
- Make description more concise. SPARCstations are no longer a
  meaningful metric.
* Sat Oct 10 2015 p.drouand@gmail.com
- Update to version 1.0.14
  * No changelog available
- Update libgsm-1.0.13.patch
- Use download Url as source
- Remove depreciated AUTHORS and clean sections
* Tue Aug 20 2013 mardnh@gmx.de
- fix URL (see http://www.quut.com/gsm/)
* Mon Aug 20 2012 cfarrell@suse.com
- license update: ISC
  [#]License is more akin to ISC (see http://www.spdx.org/licenses/ISC) than
  to BSD-3-Clause
* Fri Sep 23 2011 meissner@suse.de
- remove libgsm-32bit from requires
* Fri Sep 23 2011 meissner@suse.de
- add 32bit development headers for 32bit Wine on 64bit builds
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Mon Aug 10 2009 meissner@suse.de
- added baselibs.conf, libgsm is now used by wine
* Thu Aug  6 2009 sbrabec@suse.cz
- Updated to version 1.0.13:
  * cleaner wording of copyright
* Sat Apr  4 2009 crrodriguez@suse.de
- remove static libraries
* Fri Feb 22 2008 sbrabec@suse.cz
- Added Provides, Obsoletes and split-provides for old names.
* Mon Jan 28 2008 sbrabec@suse.cz
- Updated to version 1.0.12:
  * removed modifiable static storage that made the library
    non-reentrant.
  * fix WAV49 implode move source archive location
- Split package according to shared library packaging policy.
* Tue Aug  8 2006 sbrabec@suse.cz
- Compile with WAV-style framing support.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan  9 2006 sbrabec@suse.cz
- New SuSE package, version 1.0.10.
